@@ -3,9 +3,9 @@
 from __future__ import absolute_import, print_function, unicode_literals
 from .containers import StoreList
 from .decoration import Decorator, decorator, method_requires_decoration, requires_decoration
-from .exceptions import DependencyException, ReaderException
+from .exceptions import DependencyException, ReaderException, WriterException
 from .fields_core import Field, Pointer, Pointers, SelfPointer, SelfPointers, Slice, Store
-from .fields_extra import DateTime, Text, RelaxedDateTime
+from .fields_extra import DateTime, Text
 from .meta import Ann, Doc, make_ann
 from .reader import Reader
 from .writer import Writer
@@ -13,4 +13,4 @@ from .writer import Writer
 from . import decorators
 
 
-__all__ = ['StoreList', 'Decorator', 'decorator', 'decorators', 'requires_decoration', 'method_requires_decoration', 'DependencyException', 'ReaderException', 'Field', 'Pointer', 'Pointers', 'SelfPointer', 'SelfPointers', 'Slice', 'Store', 'DateTime', 'RelaxedDateTime', 'Text', 'Ann', 'Doc', 'make_ann', 'Token', 'Reader', 'Writer']
+__all__ = ['StoreList', 'Decorator', 'decorator', 'decorators', 'requires_decoration', 'method_requires_decoration', 'DependencyException', 'ReaderException', 'Field', 'Pointer', 'Pointers', 'SelfPointer', 'SelfPointers', 'Slice', 'Store', 'DateTime', 'Text', 'Ann', 'Doc', 'make_ann', 'Token', 'Reader', 'Writer', 'WriterException']
